summaryrefslogtreecommitdiff
path: root/src/mm-iface-modem-3gpp-ussd.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mm-iface-modem-3gpp-ussd.h')
-rw-r--r--src/mm-iface-modem-3gpp-ussd.h85
1 files changed, 44 insertions, 41 deletions
diff --git a/src/mm-iface-modem-3gpp-ussd.h b/src/mm-iface-modem-3gpp-ussd.h
index 662d555e..8a6d2f42 100644
--- a/src/mm-iface-modem-3gpp-ussd.h
+++ b/src/mm-iface-modem-3gpp-ussd.h
@@ -40,44 +40,44 @@ struct _MMIfaceModem3gppUssd {
GTypeInterface g_iface;
/* Check for USSD support (async) */
- void (* check_support) (MMIfaceModem3gppUssd *self,
- GAsyncReadyCallback callback,
- gpointer user_data);
- gboolean (*check_support_finish) (MMIfaceModem3gppUssd *self,
- GAsyncResult *res,
- GError **error);
-
- /* Asynchronous setup of unsolicited result codes */
- void (*setup_unsolicited_result_codes) (MMIfaceModem3gppUssd *self,
- GAsyncReadyCallback callback,
- gpointer user_data);
- gboolean (*setup_unsolicited_result_codes_finish) (MMIfaceModem3gppUssd *self,
- GAsyncResult *res,
- GError **error);
-
- /* Asynchronous enabling of unsolicited result codes */
- void (*enable_unsolicited_result_codes) (MMIfaceModem3gppUssd *self,
- GAsyncReadyCallback callback,
- gpointer user_data);
- gboolean (*enable_unsolicited_result_codes_finish) (MMIfaceModem3gppUssd *self,
- GAsyncResult *res,
- GError **error);
-
- /* Asynchronous disabling of unsolicited result codes */
- void (*disable_unsolicited_result_codes) (MMIfaceModem3gppUssd *self,
- GAsyncReadyCallback callback,
- gpointer user_data);
- gboolean (*disable_unsolicited_result_codes_finish) (MMIfaceModem3gppUssd *self,
- GAsyncResult *res,
- GError **error);
-
- /* Asynchronous cleaning up of unsolicited result codes */
- void (*cleanup_unsolicited_result_codes) (MMIfaceModem3gppUssd *self,
- GAsyncReadyCallback callback,
- gpointer user_data);
- gboolean (*cleanup_unsolicited_result_codes_finish) (MMIfaceModem3gppUssd *self,
- GAsyncResult *res,
- GError **error);
+ void (* check_support) (MMIfaceModem3gppUssd *self,
+ GAsyncReadyCallback callback,
+ gpointer user_data);
+ gboolean (* check_support_finish) (MMIfaceModem3gppUssd *self,
+ GAsyncResult *res,
+ GError **error);
+
+ /* Asynchronous setup of unsolicited events */
+ void (* setup_unsolicited_events) (MMIfaceModem3gppUssd *self,
+ GAsyncReadyCallback callback,
+ gpointer user_data);
+ gboolean (* setup_unsolicited_events_finish) (MMIfaceModem3gppUssd *self,
+ GAsyncResult *res,
+ GError **error);
+
+ /* Asynchronous enabling of unsolicited events */
+ void (* enable_unsolicited_events) (MMIfaceModem3gppUssd *self,
+ GAsyncReadyCallback callback,
+ gpointer user_data);
+ gboolean (* enable_unsolicited_events_finish) (MMIfaceModem3gppUssd *self,
+ GAsyncResult *res,
+ GError **error);
+
+ /* Asynchronous disabling of unsolicited events */
+ void (* disable_unsolicited_events) (MMIfaceModem3gppUssd *self,
+ GAsyncReadyCallback callback,
+ gpointer user_data);
+ gboolean (* disable_unsolicited_events_finish) (MMIfaceModem3gppUssd *self,
+ GAsyncResult *res,
+ GError **error);
+
+ /* Asynchronous cleaning up of unsolicited events */
+ void (* cleanup_unsolicited_events) (MMIfaceModem3gppUssd *self,
+ GAsyncReadyCallback callback,
+ gpointer user_data);
+ gboolean (* cleanup_unsolicited_events_finish) (MMIfaceModem3gppUssd *self,
+ GAsyncResult *res,
+ GError **error);
/* Encode/Decode */
gchar * (*encode) (MMIfaceModem3gppUssd *self,
@@ -93,9 +93,9 @@ struct _MMIfaceModem3gppUssd {
const gchar *command,
GAsyncReadyCallback callback,
gpointer user_data);
- const gchar * (* send_finish) (MMIfaceModem3gppUssd *self,
- GAsyncResult *res,
- GError **error);
+ gchar * (* send_finish) (MMIfaceModem3gppUssd *self,
+ GAsyncResult *res,
+ GError **error);
/* Cancel */
void (* cancel) (MMIfaceModem3gppUssd *self,
@@ -107,6 +107,7 @@ struct _MMIfaceModem3gppUssd {
};
GType mm_iface_modem_3gpp_ussd_get_type (void);
+G_DEFINE_AUTOPTR_CLEANUP_FUNC (MMIfaceModem3gppUssd, g_object_unref)
/* Initialize USSD interface (async) */
void mm_iface_modem_3gpp_ussd_initialize (MMIfaceModem3gppUssd *self,
@@ -132,6 +133,8 @@ gboolean mm_iface_modem_3gpp_ussd_disable_finish (MMIfaceModem3gppUssd *self,
GAsyncResult *res,
GError **error);
+MMModem3gppUssdSessionState mm_iface_modem_3gpp_ussd_get_state (MMIfaceModem3gppUssd *self);
+
/* Property updaters */
void mm_iface_modem_3gpp_ussd_update_state (MMIfaceModem3gppUssd *self,
MMModem3gppUssdSessionState new_state);